============
Installation
============

At the command line::

    $ easy_install nose-watcher

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv nose-watcher
    $ pip install nose-watcher